import { ReflectiveInjector } from '@angular/core';
import * as firebase from 'firebase';
import { FirebaseAuth } from './firebase-auth.service';
import { FirebaseDatabase } from './firebase-database.service';
import { NativeFirebaseAuth, NativeFirebaseDatabase } from './native-firebase';
import { wrapPromise } from './utils';
var lastAppId = 0;
var FirebaseApp = (function () {
    function FirebaseApp(config, injector) {
        this.config = config;
        this.injector = injector;
        config.name = config.name || "app-" + lastAppId++;
        this.nativeApp = firebase.initializeApp(config.options, config.name);
    }
    FirebaseApp.prototype.delete = function () {
        var _this = this;
        return wrapPromise(function () { return _this.nativeApp.delete(); });
    };
    FirebaseApp.prototype.auth = function () {
        if (!this._auth) {
            var authInjector = ReflectiveInjector.resolveAndCreate([
                {
                    provide: NativeFirebaseAuth,
                    useValue: this.nativeApp.auth()
                },
                FirebaseAuth
            ], this.injector);
            this._auth = authInjector.get(FirebaseAuth);
        }
        return this._auth;
    };
    FirebaseApp.prototype.database = function () {
        if (!this._database) {
            var databaseInjector = ReflectiveInjector.resolveAndCreate([
                {
                    provide: NativeFirebaseDatabase,
                    useValue: this.nativeApp.database()
                },
                FirebaseDatabase
            ], this.injector);
            this._database = databaseInjector.get(FirebaseDatabase);
        }
        return this._database;
    };
    return FirebaseApp;
}());
export { FirebaseApp };
//# sourceMappingURL=firebase-app.service.js.map