var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@angular/core';
import { Observable, ReplaySubject } from 'rxjs';
import { NativeFirebaseAuth } from './native-firebase';
import { wrapPromise } from './utils';
import './observable/add/run-in-zone';
import { FirebaseUser, FirebaseUserCredential } from './firebase-user';
var FirebaseAuth = (function () {
    function FirebaseAuth(fbAuth) {
        this.fbAuth = fbAuth;
        this.$user = new ReplaySubject(1);
        new Observable(function (sub) { return fbAuth.onAuthStateChanged(function (user) { return sub.next(user ? new FirebaseUser(user) : null); }, function (err) { return sub.error(err); }, function () { return sub.complete(); }); })
            .runInZone()
            .subscribe(this.$user);
    }
    /**
     * @param code
     * @returns {Observable<void>} - Returns {@link ActionCodeError} if operation fails.
     */
    FirebaseAuth.prototype.applyActionCode = function (code) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.applyActionCode(code); });
    };
    /**
     * @param code
     * @returns {Observable<ActionCodeInfo>} - Returns {@link ActionCodeError} if operation fails.
     */
    FirebaseAuth.prototype.checkActionCode = function (code) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.checkActionCode(code); });
    };
    /**
     * @param code
     * @param newPassword
     * @returns {Observable<void>} - Returns {@link ConfirmPasswordResetError} if operation fails.
     */
    FirebaseAuth.prototype.confirmPasswordReset = function (code, newPassword) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.confirmPasswordReset(code, newPassword); });
    };
    /**
     *
     * @param email
     * @param password
     * @returns {Observable<FirebaseUser>} - Returns {@link CreateUserWithEmailAndPasswordError} if
     *     operation fails.
     */
    FirebaseAuth.prototype.createUserWithEmailAndPassword = function (email, password) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.createUserWithEmailAndPassword(email, password); })
            .map(function (user) { return new FirebaseUser(user); });
    };
    /**
     *
     * @param email
     * @returns {Observable<string[]>} - Returns {@link FetchProvidersForEmailError} if operation
     *     fails.
     */
    FirebaseAuth.prototype.fetchProvidersForEmail = function (email) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.fetchProvidersForEmail(email); });
    };
    /**
     * @returns {Observable<FirebaseUserCredential>} - Returns {@link GetRedirectResultError} if
     *     operation fails.
     */
    FirebaseAuth.prototype.getRedirectResult = function () {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.getRedirectResult(); })
            .map(function (cred) { return new FirebaseUserCredential(cred); });
    };
    /**
     * @param email
     * @returns {Observable<void>} - Returns {@link SendPasswordResetEmailError} if operation fails.
     */
    FirebaseAuth.prototype.sendPasswordResetEmail = function (email) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.sendPasswordResetEmail(email); });
    };
    /**
     *
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInAnonymouslyError} if operation
     *     fails.
     */
    FirebaseAuth.prototype.signInAnonymously = function () {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInAnonymously(); })
            .map(function (user) { return new FirebaseUser(user); });
    };
    /**
     * @param credential
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInWithCredentialError} if operation
     *     fails.
     */
    FirebaseAuth.prototype.signInWithCredential = function (credential) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInWithCredential(credential); })
            .map(function (user) { return new FirebaseUser(user); });
    };
    /**
     * @param token
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInWithCustomTokenError} if operation
     *     fails.
     */
    FirebaseAuth.prototype.signInWithCustomToken = function (token) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInWithCustomToken(token); })
            .map(function (user) { return new FirebaseUser(user); });
    };
    /**
     * @param email
     * @param password
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInWithEmailAndPasswordError} if
     *     operation fails.
     */
    FirebaseAuth.prototype.signInWithEmailAndPassword = function (email, password) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInWithEmailAndPassword(email, password); })
            .map(function (user) { return new FirebaseUser(user); });
    };
    /**
     * @param provider
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInWithPopupError} if operation fails.
     */
    FirebaseAuth.prototype.signInWithPopup = function (provider) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInWithPopup(provider); })
            .map(function (cred) { return new FirebaseUserCredential(cred); });
    };
    /**
     * @param provider
     * @returns {Observable<FirebaseUser>} - Returns {@link SignInWithRedirectError} if operation
     *     fails.
     */
    FirebaseAuth.prototype.signInWithRedirect = function (provider) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signInWithRedirect(provider); })
            .map(function (cred) { return new FirebaseUserCredential(cred); });
    };
    FirebaseAuth.prototype.signOut = function () {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.signOut(); });
    };
    /**
     *
     * @param code
     * @returns {Observable<string>} - Returns {@link VerifyPasswordResetCodeError} if operation
     * fails.
     */
    FirebaseAuth.prototype.verifyPasswordResetCode = function (code) {
        var _this = this;
        return wrapPromise(function () { return _this.fbAuth.verifyPasswordResetCode(code); });
    };
    return FirebaseAuth;
}());
FirebaseAuth = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [NativeFirebaseAuth])
], FirebaseAuth);
export { FirebaseAuth };
//# sourceMappingURL=firebase-auth.service.js.map