import { Observable } from 'rxjs';
import { database } from 'firebase';
import { NativeFirebaseDatabase } from './native-firebase';
import { DataSnapshot } from './reexports';
import { DataSnapshotObservable } from './observable/data-snapshot-observable';
import './observable/add/run-in-zone';
export declare type NativeDatabaseRef = database.Reference;
export declare type Query = database.Query;
export declare type EventType = 'value' | 'child_added' | 'child_changed' | 'child_removed' | 'child_moved';
export declare class Event {
    static Value: EventType;
    static ChildAdded: EventType;
    static ChildChanged: EventType;
    static ChildRemoved: EventType;
    static ChildMoved: EventType;
}
export declare class FirebaseQuery<T> {
    protected _ref: NativeDatabaseRef;
    private query;
    protected wrappedRef: FirebaseDatabaseRef<T>;
    readonly ref: FirebaseDatabaseRef<T>;
    constructor(_ref: NativeDatabaseRef);
    orderByChild(child: string): FirebaseQuery<T>;
    orderByKey(): FirebaseQuery<T>;
    orderByPriority(): FirebaseQuery<T>;
    orderByValue(): FirebaseQuery<T>;
    startAt(value: number | string | boolean | null, key?: string): FirebaseQuery<T>;
    endAt(value: number | string | boolean | null, key?: string): FirebaseQuery<T>;
    equalTo(value: number | string | boolean | null, key?: string): FirebaseQuery<T>;
    limitToFirst(limit: number): FirebaseQuery<T>;
    limitToLast(limit: number): FirebaseQuery<T>;
    once(event: EventType): DataSnapshotObservable<T>;
    onceValue(): DataSnapshotObservable<T>;
    onceChildAdded(): DataSnapshotObservable<T>;
    onceChildChanged(): DataSnapshotObservable<T>;
    onceChildMoved(): DataSnapshotObservable<T>;
    onceChildRemoved(): DataSnapshotObservable<T>;
    on(event: EventType): DataSnapshotObservable<T>;
    onValue(): DataSnapshotObservable<T>;
    onChildAdded(): DataSnapshotObservable<T>;
    onChildChanged(): DataSnapshotObservable<T>;
    onChildMoved(): DataSnapshotObservable<T>;
    onChildRemoved(): DataSnapshotObservable<T>;
    isEqual(query: FirebaseQuery<any>): boolean;
    private getEventHandler(sub, complete?);
    private getQueryOrRef();
    private _call(fnName, ...args);
}
export declare class FirebaseDatabaseRefConfig {
    parent: FirebaseDatabaseRef<any> | null;
    ref: NativeDatabaseRef;
    constructor(parent: FirebaseDatabaseRef<any> | null, ref: NativeDatabaseRef);
}
export declare class FirebaseDatabaseRef<T> extends FirebaseQuery<T> {
    private config;
    static create<T>(parent: FirebaseDatabaseRef<any> | null, ref: NativeDatabaseRef): FirebaseDatabaseRef<T>;
    readonly key: string | null;
    constructor(config: FirebaseDatabaseRefConfig);
    child<P extends keyof T>(path: P): FirebaseDatabaseRef<T[P]>;
    set(value: any): Observable<void>;
    setPriority(priority: string | number | null): Observable<void>;
    setWithPriority(newVal: any, priority: string | number | null): Observable<void>;
    push<P>(value?: P): Observable<FirebaseDatabaseRef<P>>;
    update(value: Object): Observable<void>;
    remove(): Observable<void>;
    transaction(transactionUpdate: (node: any) => any | never, applyLocally?: boolean): Observable<{
        committed: boolean;
        snapshot: DataSnapshot;
    }>;
}
export declare class FirebaseDatabase<T> {
    private db;
    constructor(db: NativeFirebaseDatabase);
    ref(): FirebaseDatabaseRef<T>;
    ref(path: string): FirebaseDatabaseRef<any>;
    ref<F>(path: string): FirebaseDatabaseRef<F>;
}
