import { UserInfo } from 'firebase';
import { Observable } from 'rxjs';
import { auth, User } from 'firebase';
import { FirebaseError } from './native-firebase';
import { AuthCredential } from './reexports';
import { AuthErrorCodeType } from './firebase-auth.service';
export declare type UserCredential = auth.UserCredential;
export declare class FirebaseUserCredential {
    credential?: AuthCredential;
    user?: FirebaseUser;
    constructor(cred: UserCredential);
}
export interface DeleteUserError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/requires-recent-login';
}
export interface LinkUserError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/provider-already-linked' | 'auth/invalid-credential' | 'auth/credential-already-in-use' | 'auth/email-already-in-use' | 'auth/operation-not-allowed' | 'auth/invalid-email' | 'auth/wrong-password';
}
export interface LinkUserWithPopupError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/auth-domain-config-required' | 'auth/cancelled-popup-request' | 'auth/credential-already-in-use' | 'auth/email-already-in-use' | 'auth/operation-not-allowed' | 'auth/popup-blocked' | 'auth/operation-not-supported-in-this-environment' | 'auth/popup-closed-by-user' | 'auth/provider-already-linked' | 'auth/unauthorized-domain';
}
export interface LinkUserWithRedirectError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/auth-domain-config-required' | 'auth/operation-not-supported-in-this-environment' | 'auth/provider-already-linked' | 'auth/unauthorized-domain';
}
export interface ReauthenticateError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/user-mismatch' | 'auth/user-not-found' | 'auth/invalid-credential' | 'auth/invalid-email' | 'auth/wrong-password';
}
export interface UpdateEmailError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/invalid-email' | 'auth/email-already-in-use' | 'auth/requires-recent-login';
}
export interface UpdatePasswordError extends FirebaseError {
    code: AuthErrorCodeType | 'auth/weak-password' | 'auth/requires-recent-login';
}
export declare class FirebaseUser {
    private user;
    readonly displayName: string | null;
    readonly email: string | null;
    readonly emailVerified: boolean;
    readonly isAnonymous: boolean;
    readonly photoURL: string | null;
    readonly providerData: (UserInfo | null)[];
    readonly providerId: string;
    readonly refreshToken: string;
    readonly uid: string;
    constructor(user: User);
    /**
     * @returns {Observable<void>} - Returns {@link DeleteUserError} if operation fails.
     */
    delete(): Observable<void>;
    getToken(forceRefresh?: boolean): Observable<string>;
    /**
     * @returns {Observable<FirebaseUser>} - Returns {@link LinkUserError} if operation fails.
     */
    link(credential: AuthCredential): Observable<FirebaseUser>;
    /**
     * @returns {Observable<FirebaseUserCredential>} - Returns {@link LinkUserWithPopupError} if
     *     operation fails.
     */
    linkWithPopup(provider: auth.AuthProvider): Observable<FirebaseUserCredential>;
    /**
     * @returns {Observable<FirebaseUserCredential>} - Returns {@link LinkUserWithRedirectError} if
     *     operation fails.
     */
    linkWithRedirect(provider: auth.AuthProvider): Observable<FirebaseUserCredential>;
    /**
     * @returns {Observable<void>} - Returns {@link ReauthenticateError} if operation
     * fails.
     */
    reauthenticate(credential: AuthCredential): Observable<void>;
    reload(): Observable<void>;
    sendEmailVerification(): Observable<void>;
    unlink(providerId: string): Observable<FirebaseUser>;
    /**
     * @returns {Observable<void>} - Returns {@link UpdateEmailError} if operation
     * fails.
     */
    updateEmail(newEmail: string): Observable<void>;
    /**
     * @returns {Observable<void>} - Returns {@link UpdatePasswordError} if operation
     * fails.
     */
    updatePassword(newPassword: string): Observable<void>;
    updateProfile(profile: {
        displayName?: string;
        photoURL?: string;
    }): Observable<void>;
}
